==> styled-components-0.1.1.tgz: package/lib/constructors/test/styled.test.js <==
'use strict';

var _templateObject = _taggedTemplateLiteral(['background-color: blue;'], ['background-color: blue;']),
    _templateObject2 = _taggedTemplateLiteral(['background-color: ', ';'], ['background-color: ', ';']),
    _templateObject3 = _taggedTemplateLiteral(['', ''], ['', '']);

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _styled = require('../styled');

var _styled2 = _interopRequireDefault(_styled);

var _element = require('../element');

var _element2 = _interopRequireDefault(_element);

var _css = require('../css');

var _css2 = _interopRequireDefault(_css);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

describe('styled', function () {
  it('should handle template strings', function () {
    var tagName = 'div';
    (0, _expect2.default)((0, _styled2.default)(tagName)(_templateObject)).toEqual((0, _element2.default)(tagName, (0, _css2.default)('background-color: blue')));
  });

  it('should handle tagged template strings', function () {
    var tagName = 'div';
    var bgColor = 'blue';
    (0, _expect2.default)((0, _styled2.default)(tagName)(_templateObject2, bgColor)).toEqual((0, _element2.default)(tagName, (0, _css2.default)(_templateObject2, bgColor)));
  });

  it('should handle CSS in JS', function () {
    var tagName = 'div';
    var styles = {
      backgroundColor: 'blue'
    };
    (0, _expect2.default)((0, _styled2.default)(tagName)('' + styles)).toEqual((0, _element2.default)(tagName, (0, _css2.default)(_templateObject3, styles)));
  });

  it('should have all valid HTML5 elements defined as properties', function () {
    (0, _expect2.default)(_styled2.default.a).toExist();
    (0, _expect2.default)(_styled2.default.abbr).toExist();
    (0, _expect2.default)(_styled2.default.address).toExist();
    (0, _expect2.default)(_styled2.default.area).toExist();
    (0, _expect2.default)(_styled2.default.article).toExist();
    (0, _expect2.default)(_styled2.default.aside).toExist();
    (0, _expect2.default)(_styled2.default.audio).toExist();
    (0, _expect2.default)(_styled2.default.b).toExist();
    (0, _expect2.default)(_styled2.default.base).toExist();
    (0, _expect2.default)(_styled2.default.bdi).toExist();
    (0, _expect2.default)(_styled2.default.bdo).toExist();
    (0, _expect2.default)(_styled2.default.big).toExist();
    (0, _expect2.default)(_styled2.default.blockquote).toExist();
    (0, _expect2.default)(_styled2.default.body).toExist();
    (0, _expect2.default)(_styled2.default.br).toExist();
    (0, _expect2.default)(_styled2.default.button).toExist();
    (0, _expect2.default)(_styled2.default.canvas).toExist();
    (0, _expect2.default)(_styled2.default.caption).toExist();
    (0, _expect2.default)(_styled2.default.cite).toExist();
    (0, _expect2.default)(_styled2.default.code).toExist();
    (0, _expect2.default)(_styled2.default.col).toExist();
    (0, _expect2.default)(_styled2.default.colgroup).toExist();
    (0, _expect2.default)(_styled2.default.data).toExist();
    (0, _expect2.default)(_styled2.default.datalist).toExist();
    (0, _expect2.default)(_styled2.default.dd).toExist();
    (0, _expect2.default)(_styled2.default.del).toExist();
    (0, _expect2.default)(_styled2.default.details).toExist();
    (0, _expect2.default)(_styled2.default.dfn).toExist();
    (0, _expect2.default)(_styled2.default.dialog).toExist();
    (0, _expect2.default)(_styled2.default.div).toExist();
    (0, _expect2.default)(_styled2.default.dl).toExist();
    (0, _expect2.default)(_styled2.default.dt).toExist();
    (0, _expect2.default)(_styled2.default.em).toExist();
    (0, _expect2.default)(_styled2.default.embed).toExist();
    (0, _expect2.default)(_styled2.default.fieldset).toExist();
    (0, _expect2.default)(_styled2.default.figcaption).toExist();
    (0, _expect2.default)(_styled2.default.figure).toExist();
    (0, _expect2.default)(_styled2.default.footer).toExist();
    (0, _expect2.default)(_styled2.default.form).toExist();
    (0, _expect2.default)(_styled2.default.h1).toExist();
    (0, _expect2.default)(_styled2.default.h2).toExist();
    (0, _expect2.default)(_styled2.default.h3).toExist();
    (0, _expect2.default)(_styled2.default.h4).toExist();
    (0, _expect2.default)(_styled2.default.h5).toExist();
    (0, _expect2.default)(_styled2.default.h6).toExist();
    (0, _expect2.default)(_styled2.default.head).toExist();
    (0, _expect2.default)(_styled2.default.header).toExist();
    (0, _expect2.default)(_styled2.default.hgroup).toExist();
    (0, _expect2.default)(_styled2.default.hr).toExist();
    (0, _expect2.default)(_styled2.default.html).toExist();
    (0, _expect2.default)(_styled2.default.i).toExist();
    (0, _expect2.default)(_styled2.default.iframe).toExist();
    (0, _expect2.default)(_styled2.default.img).toExist();
    (0, _expect2.default)(_styled2.default.input).toExist();
    (0, _expect2.default)(_styled2.default.ins).toExist();
    (0, _expect2.default)(_styled2.default.kbd).toExist();
    (0, _expect2.default)(_styled2.default.keygen).toExist();
    (0, _expect2.default)(_styled2.default.label).toExist();
    (0, _expect2.default)(_styled2.default.legend).toExist();
    (0, _expect2.default)(_styled2.default.li).toExist();
    (0, _expect2.default)(_styled2.default.link).toExist();
    (0, _expect2.default)(_styled2.default.main).toExist();
    (0, _expect2.default)(_styled2.default.map).toExist();
    (0, _expect2.default)(_styled2.default.mark).toExist();
    (0, _expect2.default)(_styled2.default.menu).toExist();
    (0, _expect2.default)(_styled2.default.menuitem).toExist();
    (0, _expect2.default)(_styled2.default.meta).toExist();
    (0, _expect2.default)(_styled2.default.meter).toExist();
    (0, _expect2.default)(_styled2.default.nav).toExist();
    (0, _expect2.default)(_styled2.default.noscript).toExist();
    (0, _expect2.default)(_styled2.default.object).toExist();
    (0, _expect2.default)(_styled2.default.ol).toExist();
    (0, _expect2.default)(_styled2.default.optgroup).toExist();
    (0, _expect2.default)(_styled2.default.option).toExist();
    (0, _expect2.default)(_styled2.default.output).toExist();
    (0, _expect2.default)(_styled2.default.p).toExist();
    (0, _expect2.default)(_styled2.default.param).toExist();
    (0, _expect2.default)(_styled2.default.picture).toExist();
    (0, _expect2.default)(_styled2.default.pre).toExist();
    (0, _expect2.default)(_styled2.default.progress).toExist();
    (0, _expect2.default)(_styled2.default.q).toExist();
    (0, _expect2.default)(_styled2.default.rp).toExist();
    (0, _expect2.default)(_styled2.default.rt).toExist();
    (0, _expect2.default)(_styled2.default.ruby).toExist();
    (0, _expect2.default)(_styled2.default.s).toExist();
    (0, _expect2.default)(_styled2.default.samp).toExist();
    (0, _expect2.default)(_styled2.default.script).toExist();
    (0, _expect2.default)(_styled2.default.section).toExist();
    (0, _expect2.default)(_styled2.default.select).toExist();
    (0, _expect2.default)(_styled2.default.small).toExist();
    (0, _expect2.default)(_styled2.default.source).toExist();
    (0, _expect2.default)(_styled2.default.span).toExist();
    (0, _expect2.default)(_styled2.default.strong).toExist();
    (0, _expect2.default)(_styled2.default.style).toExist();
    (0, _expect2.default)(_styled2.default.sub).toExist();
    (0, _expect2.default)(_styled2.default.summary).toExist();
    (0, _expect2.default)(_styled2.default.sup).toExist();
    (0, _expect2.default)(_styled2.default.table).toExist();
    (0, _expect2.default)(_styled2.default.tbody).toExist();
    (0, _expect2.default)(_styled2.default.td).toExist();
    (0, _expect2.default)(_styled2.default.textarea).toExist();
    (0, _expect2.default)(_styled2.default.tfoot).toExist();
    (0, _expect2.default)(_styled2.default.th).toExist();
    (0, _expect2.default)(_styled2.default.thead).toExist();
    (0, _expect2.default)(_styled2.default.time).toExist();
    (0, _expect2.default)(_styled2.default.title).toExist();
    (0, _expect2.default)(_styled2.default.tr).toExist();
    (0, _expect2.default)(_styled2.default.track).toExist();
    (0, _expect2.default)(_styled2.default.u).toExist();
    (0, _expect2.default)(_styled2.default.ul).toExist();
    (0, _expect2.default)(_styled2.default.var).toExist();
    (0, _expect2.default)(_styled2.default.video).toExist();
    (0, _expect2.default)(_styled2.default.wbr).toExist();
    (0, _expect2.default)(_styled2.default.circle).toExist();
    (0, _expect2.default)(_styled2.default.clipPath).toExist();
    (0, _expect2.default)(_styled2.default.defs).toExist();
    (0, _expect2.default)(_styled2.default.ellipse).toExist();
    (0, _expect2.default)(_styled2.default.g).toExist();
    (0, _expect2.default)(_styled2.default.image).toExist();
    (0, _expect2.default)(_styled2.default.line).toExist();
    (0, _expect2.default)(_styled2.default.linearGradient).toExist();
    (0, _expect2.default)(_styled2.default.mask).toExist();
    (0, _expect2.default)(_styled2.default.path).toExist();
    (0, _expect2.default)(_styled2.default.pattern).toExist();
    (0, _expect2.default)(_styled2.default.polygon).toExist();
    (0, _expect2.default)(_styled2.default.polyline).toExist();
    (0, _expect2.default)(_styled2.default.radialGradient).toExist();
    (0, _expect2.default)(_styled2.default.rect).toExist();
    (0, _expect2.default)(_styled2.default.stop).toExist();
    (0, _expect2.default)(_styled2.default.svg).toExist();
    (0, _expect2.default)(_styled2.default.text).toExist();
    (0, _expect2.default)(_styled2.default.tspan).toExist();
  });
});

==> styled-components-0.1.5.tgz: package/lib/constructors/test/styled.test.js <==
'use strict';

var _templateObject = _taggedTemplateLiteral(['background-color: blue;'], ['background-color: blue;']),
    _templateObject2 = _taggedTemplateLiteral(['background-color: ', ';'], ['background-color: ', ';']),
    _templateObject3 = _taggedTemplateLiteral(['', ''], ['', '']);

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _styled = require('../styled');

var _styled2 = _interopRequireDefault(_styled);

var _StyledComponent = require('../../models/StyledComponent');

var _StyledComponent2 = _interopRequireDefault(_StyledComponent);

var _css = require('../css');

var _css2 = _interopRequireDefault(_css);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

describe('styled', function () {
  it('should handle template strings', function () {
    var tagName = 'div';
    (0, _expect2.default)((0, _styled2.default)(tagName)(_templateObject)).toEqual((0, _StyledComponent2.default)(tagName, (0, _css2.default)('background-color: blue')));
  });

  it('should handle tagged template strings', function () {
    var tagName = 'div';
    var bgColor = 'blue';
    (0, _expect2.default)((0, _styled2.default)(tagName)(_templateObject2, bgColor)).toEqual((0, _StyledComponent2.default)(tagName, (0, _css2.default)(_templateObject2, bgColor)));
  });

  it('should handle CSS in JS', function () {
    var tagName = 'div';
    var styles = {
      backgroundColor: 'blue'
    };
    (0, _expect2.default)((0, _styled2.default)(tagName)('' + styles)).toEqual((0, _StyledComponent2.default)(tagName, (0, _css2.default)(_templateObject3, styles)));
  });

  it('should have all valid HTML5 elements defined as properties', function () {
    (0, _expect2.default)(_styled2.default.a).toExist();
    (0, _expect2.default)(_styled2.default.abbr).toExist();
    (0, _expect2.default)(_styled2.default.address).toExist();
    (0, _expect2.default)(_styled2.default.area).toExist();
    (0, _expect2.default)(_styled2.default.article).toExist();
    (0, _expect2.default)(_styled2.default.aside).toExist();
    (0, _expect2.default)(_styled2.default.audio).toExist();
    (0, _expect2.default)(_styled2.default.b).toExist();
    (0, _expect2.default)(_styled2.default.base).toExist();
    (0, _expect2.default)(_styled2.default.bdi).toExist();
    (0, _expect2.default)(_styled2.default.bdo).toExist();
    (0, _expect2.default)(_styled2.default.big).toExist();
    (0, _expect2.default)(_styled2.default.blockquote).toExist();
    (0, _expect2.default)(_styled2.default.body).toExist();
    (0, _expect2.default)(_styled2.default.br).toExist();
    (0, _expect2.default)(_styled2.default.button).toExist();
    (0, _expect2.default)(_styled2.default.canvas).toExist();
    (0, _expect2.default)(_styled2.default.caption).toExist();
    (0, _expect2.default)(_styled2.default.cite).toExist();
    (0, _expect2.default)(_styled2.default.code).toExist();
    (0, _expect2.default)(_styled2.default.col).toExist();
    (0, _expect2.default)(_styled2.default.colgroup).toExist();
    (0, _expect2.default)(_styled2.default.data).toExist();
    (0, _expect2.default)(_styled2.default.datalist).toExist();
    (0, _expect2.default)(_styled2.default.dd).toExist();
    (0, _expect2.default)(_styled2.default.del).toExist();
    (0, _expect2.default)(_styled2.default.details).toExist();
    (0, _expect2.default)(_styled2.default.dfn).toExist();
    (0, _expect2.default)(_styled2.default.dialog).toExist();
    (0, _expect2.default)(_styled2.default.div).toExist();
    (0, _expect2.default)(_styled2.default.dl).toExist();
    (0, _expect2.default)(_styled2.default.dt).toExist();
    (0, _expect2.default)(_styled2.default.em).toExist();
    (0, _expect2.default)(_styled2.default.embed).toExist();
    (0, _expect2.default)(_styled2.default.fieldset).toExist();
    (0, _expect2.default)(_styled2.default.figcaption).toExist();
    (0, _expect2.default)(_styled2.default.figure).toExist();
    (0, _expect2.default)(_styled2.default.footer).toExist();
    (0, _expect2.default)(_styled2.default.form).toExist();
    (0, _expect2.default)(_styled2.default.h1).toExist();
    (0, _expect2.default)(_styled2.default.h2).toExist();
    (0, _expect2.default)(_styled2.default.h3).toExist();
    (0, _expect2.default)(_styled2.default.h4).toExist();
    (0, _expect2.default)(_styled2.default.h5).toExist();
    (0, _expect2.default)(_styled2.default.h6).toExist();
    (0, _expect2.default)(_styled2.default.head).toExist();
    (0, _expect2.default)(_styled2.default.header).toExist();
    (0, _expect2.default)(_styled2.default.hgroup).toExist();
    (0, _expect2.default)(_styled2.default.hr).toExist();
    (0, _expect2.default)(_styled2.default.html).toExist();
    (0, _expect2.default)(_styled2.default.i).toExist();
    (0, _expect2.default)(_styled2.default.iframe).toExist();
    (0, _expect2.default)(_styled2.default.img).toExist();
    (0, _expect2.default)(_styled2.default.input).toExist();
    (0, _expect2.default)(_styled2.default.ins).toExist();
    (0, _expect2.default)(_styled2.default.kbd).toExist();
    (0, _expect2.default)(_styled2.default.keygen).toExist();
    (0, _expect2.default)(_styled2.default.label).toExist();
    (0, _expect2.default)(_styled2.default.legend).toExist();
    (0, _expect2.default)(_styled2.default.li).toExist();
    (0, _expect2.default)(_styled2.default.link).toExist();
    (0, _expect2.default)(_styled2.default.main).toExist();
    (0, _expect2.default)(_styled2.default.map).toExist();
    (0, _expect2.default)(_styled2.default.mark).toExist();
    (0, _expect2.default)(_styled2.default.menu).toExist();
    (0, _expect2.default)(_styled2.default.menuitem).toExist();
    (0, _expect2.default)(_styled2.default.meta).toExist();
    (0, _expect2.default)(_styled2.default.meter).toExist();
    (0, _expect2.default)(_styled2.default.nav).toExist();
    (0, _expect2.default)(_styled2.default.noscript).toExist();
    (0, _expect2.default)(_styled2.default.object).toExist();
    (0, _expect2.default)(_styled2.default.ol).toExist();
    (0, _expect2.default)(_styled2.default.optgroup).toExist();
    (0, _expect2.default)(_styled2.default.option).toExist();
    (0, _expect2.default)(_styled2.default.output).toExist();
    (0, _expect2.default)(_styled2.default.p).toExist();
    (0, _expect2.default)(_styled2.default.param).toExist();
    (0, _expect2.default)(_styled2.default.picture).toExist();
    (0, _expect2.default)(_styled2.default.pre).toExist();
    (0, _expect2.default)(_styled2.default.progress).toExist();
    (0, _expect2.default)(_styled2.default.q).toExist();
    (0, _expect2.default)(_styled2.default.rp).toExist();
    (0, _expect2.default)(_styled2.default.rt).toExist();
    (0, _expect2.default)(_styled2.default.ruby).toExist();
    (0, _expect2.default)(_styled2.default.s).toExist();
    (0, _expect2.default)(_styled2.default.samp).toExist();
    (0, _expect2.default)(_styled2.default.script).toExist();
    (0, _expect2.default)(_styled2.default.section).toExist();
    (0, _expect2.default)(_styled2.default.select).toExist();
    (0, _expect2.default)(_styled2.default.small).toExist();
    (0, _expect2.default)(_styled2.default.source).toExist();
    (0, _expect2.default)(_styled2.default.span).toExist();
    (0, _expect2.default)(_styled2.default.strong).toExist();
    (0, _expect2.default)(_styled2.default.style).toExist();
    (0, _expect2.default)(_styled2.default.sub).toExist();
    (0, _expect2.default)(_styled2.default.summary).toExist();
    (0, _expect2.default)(_styled2.default.sup).toExist();
    (0, _expect2.default)(_styled2.default.table).toExist();
    (0, _expect2.default)(_styled2.default.tbody).toExist();
    (0, _expect2.default)(_styled2.default.td).toExist();
    (0, _expect2.default)(_styled2.default.textarea).toExist();
    (0, _expect2.default)(_styled2.default.tfoot).toExist();
    (0, _expect2.default)(_styled2.default.th).toExist();
    (0, _expect2.default)(_styled2.default.thead).toExist();
    (0, _expect2.default)(_styled2.default.time).toExist();
    (0, _expect2.default)(_styled2.default.title).toExist();
    (0, _expect2.default)(_styled2.default.tr).toExist();
    (0, _expect2.default)(_styled2.default.track).toExist();
    (0, _expect2.default)(_styled2.default.u).toExist();
    (0, _expect2.default)(_styled2.default.ul).toExist();
    (0, _expect2.default)(_styled2.default.var).toExist();
    (0, _expect2.default)(_styled2.default.video).toExist();
    (0, _expect2.default)(_styled2.default.wbr).toExist();
    (0, _expect2.default)(_styled2.default.circle).toExist();
    (0, _expect2.default)(_styled2.default.clipPath).toExist();
    (0, _expect2.default)(_styled2.default.defs).toExist();
    (0, _expect2.default)(_styled2.default.ellipse).toExist();
    (0, _expect2.default)(_styled2.default.g).toExist();
    (0, _expect2.default)(_styled2.default.image).toExist();
    (0, _expect2.default)(_styled2.default.line).toExist();
    (0, _expect2.default)(_styled2.default.linearGradient).toExist();
    (0, _expect2.default)(_styled2.default.mask).toExist();
    (0, _expect2.default)(_styled2.default.path).toExist();
    (0, _expect2.default)(_styled2.default.pattern).toExist();
    (0, _expect2.default)(_styled2.default.polygon).toExist();
    (0, _expect2.default)(_styled2.default.polyline).toExist();
    (0, _expect2.default)(_styled2.default.radialGradient).toExist();
    (0, _expect2.default)(_styled2.default.rect).toExist();
    (0, _expect2.default)(_styled2.default.stop).toExist();
    (0, _expect2.default)(_styled2.default.svg).toExist();
    (0, _expect2.default)(_styled2.default.text).toExist();
    (0, _expect2.default)(_styled2.default.tspan).toExist();
  });
});
